summaryrefslogtreecommitdiffstats
path: root/job-cfg
diff options
context:
space:
mode:
Diffstat (limited to 'job-cfg')
-rwxr-xr-xjob-cfg/chroot-installation.yaml.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/job-cfg/chroot-installation.yaml.py b/job-cfg/chroot-installation.yaml.py
index e62ecb2e..c19c7488 100755
--- a/job-cfg/chroot-installation.yaml.py
+++ b/job-cfg/chroot-installation.yaml.py
@@ -80,8 +80,8 @@ def get_targets_in_distro(distro, targets):
# qt5, education-desktop-mate and cinnamon weren't in wheezy
if distro == 'wheezy' and ( target == 'education-desktop-mate' or target == 'cinnamon' or target == 'qt5' ):
continue
- # sugar has been removed from jessie and thus education-desktop-sugar has been removed from jessie and sid
- if (distro == 'sid' or distro == 'jessie') and ( target == 'education-desktop-sugar' ):
+ # sugar has been removed from jessie and thus education-desktop-sugar has been removed from jessie and sid - it's also not yet available in stretch again...
+ if (distro == 'sid' or distro == 'jessie' or distro == 'stretch') and ( target == 'education-desktop-sugar' ):
continue
targets_in_distro.append(target)
return targets_in_distro